@@ -5,13 +5,19 @@
  *  SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #include "waylandoutputdevice.h"
-#include "../utils.h"
 #include "waylandoutputmanagement.h"
 
 #include "kscreen_kwayland_logging.h"
 
+#include "../utils.h"
+
+#include <mode.h>
+#include <output.h>
+
 #include <wayland-server-protocol.h>
 
+#include <utility>
+
 using namespace KScreen;
 
 WaylandOutputDevice::WaylandOutputDevice(int id)
@@ -137,7 +143,7 @@ void KScreen::WaylandOutputDevice::updateKScreenModes(OutputPtr &output)
     QString currentModeId = QStringLiteral("-1");
     int modeId = 0;
 
-    for (const WaylandOutputDeviceMode *wlMode : qAsConst(m_modes)) {
+    for (const WaylandOutputDeviceMode *wlMode : std::as_const(m_modes)) {
         ModePtr mode(new Mode());
 
         const QString modeIdStr = QString::number(modeId);
@@ -170,7 +176,6 @@ void WaylandOutputDevice::updateKScreenOutput(OutputPtr &output)
     output->setId(m_id);
     output->setEnabled(enabled());
     output->setConnected(true);
-    output->setPrimary(m_isPrimary);
     output->setName(name());
     output->setSizeMm(m_physicalSize);
     output->setPos(m_pos);
@@ -256,11 +261,13 @@ bool WaylandOutputDevice::setWlConfig(WaylandOutputConfiguration *wlConfig, cons
         wlConfig->set_rgb_range(object(), static_cast<uint32_t>(output->rgbRange()));
         changed = true;
     }
-
-    if (output->isPrimary()) {
-        wlConfig->set_primary_output(object());
+    if (output->priority() != m_index) {
         changed = true;
     }
+    // always send all outputs
+    if (kde_output_configuration_v2_get_version(wlConfig->object()) >= KDE_OUTPUT_CONFIGURATION_V2_SET_PRIORITY_SINCE_VERSION) {
+        wlConfig->set_priority(object(), output->priority());
+    }
 
     return changed;
 }
@@ -282,14 +289,14 @@ QDebug operator<<(QDebug dbg, const WaylandOutputDevice *output)
     return dbg;
 }
 
-bool WaylandOutputDevice::isPrimary() const
+void WaylandOutputDevice::setIndex(uint32_t index)
 {
-    return m_isPrimary;
+    m_index = index;
 }
 
-void WaylandOutputDevice::setPrimary(bool primary)
+uint32_t WaylandOutputDevice::index() const
 {
-    m_isPrimary = primary;
+    return m_index;
 }
 
 void WaylandOutputDevice::kde_output_device_v2_done()
